@@ -8,14 +8,14 @@ Vue.component('sub-menu', {
     template: `
         <div>
             <template v-for="(item,i) in menus" :key="item.eid">
-                <el-menu-item :index="item.eid" v-if="!item.models" @click="openTab(item,item.eid)">
-                    <i :class="item.icon"></i>
-                    <span slot="title" v-text="item.name"></span>
+                <el-menu-item  :index="item.eid" v-if="!item.models" @click="openTab(item,item.eid)">
+                    <i :class="'menu-icon '+item.icon"></i>
+                    <span v-show="!fold" slot="title" v-text="item.name"></span>
                 </el-menu-item>
                 <el-submenu :index="item.eid" v-else>
                     <template slot="title">
-                        <i :class="item.icon"></i>
-                        <span v-text="item.name"></span>
+                        <i :class="'menu-icon '+item.icon"></i>
+                        <span v-show="!fold" v-text="item.name"></span>
                     </template>
                    <sub-menu :menus="item.models"></sub-menu>
                 </el-submenu>
@@ -25,9 +25,9 @@ Vue.component('sub-menu', {
 
 });
 Vue.component('multiple-menu', {
-    props: ['menus', 'openTab', 'menuActive', 'fold'],
+    props: ['menus', 'menuActive', 'fold'],
     template: `
-     <el-menu :unique-opened="true" :default-active="menuActive+''" :collapse="fold">
+     <el-menu :unique-opened="true" :default-active="menuActive" :collapse="fold" :collapse-transition="true">
         <sub-menu :menus="menus" :fold="fold"></sub-menu>
     </el-menu>
     `
